<?php declare(strict_types=1);
error_reporting(E_ERROR | E_PARSE);

require_once './vendor/autoload.php';

use ImageResizer\Lib\FileLogger;
use ImageResizer\Lib\Resizer;
use ImageResizer\Lib\SqliteImageDb;
use ImageResizer\Models\ResizeParams;

$logger = new FileLogger("resizer.log");
$dotenv = Dotenv\Dotenv::createImmutable([__DIR__, __DIR__ . "/.."]);
$dotenv->load();

$pdo = new PDO("sqlite:".$_ENV["DB_NAME"]);
$imageDb = new SqliteImageDb($pdo, $logger);

$imgPath = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
$params = new ResizeParams($_GET);

$resizer = new Resizer($imageDb, $logger);

try {
    $image = $resizer->performResize($imgPath, $params);
    header("Cache-Control: max-age=86400, public");
    echo $image;
} catch (\Exception $e) {
    $logger->error($e->getMessage());
    http_response_code(500);
    echo "Internal Server Error";
}